@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,33 +17,13 @@ from .empty_object_schema import EMPTY_OBJECT
 
 
 VARIATION = {
-    'type': 'object',
-    'properties': {
-        'id': {
-            'type': ['number', 'string']
-        },
-        'name': {
-            'type': ['string']
-        },
-        'weight': {
-            'type': ['number', 'string']
-        },
-        'variables': {
-            'if': {
-                'type': 'array',
-            },
-            'then': {
-                'items': VARIABLE
-            },
-            'else': EMPTY_OBJECT
-        },
-        'isFeatureEnabled': {
-            'type': 'boolean'
-        }
+    "type": "object",
+    "properties": {
+        "id": {"type": ["number", "string"]},
+        "name": {"type": ["string"]},
+        "weight": {"type": ["number", "string"]},
+        "variables": {"if": {"type": "array"}, "then": {"items": VARIABLE}, "else": EMPTY_OBJECT},
+        "isFeatureEnabled": {"type": "boolean"},
     },
-    'required': [
-        'id',
-        'name',
-        'weight'
-    ]
+    "required": ["id", "name", "weight"],
 }
